@@ -309,7 +309,15 @@ def render_attr_bar(doc, fill_rate):
         with doc.tag("tr"):
             if fill_rate >= 0.01:
                 s = "%.2f%%" % fill_rate
-                doc.line("td", s, width=s, style="background-color: #1de9B6")
+                # For fill rates less than 1, use 1% as the HTML
+                # display width, otherwise the bar will not be drawn
+                # properly (due to HTML not supporting widths lower than 1%).
+                # https://github.com/DemystData/demyst-python/issues/733
+                if fill_rate < 1:
+                    html_width = "1%"
+                else:
+                    html_width = s
+                doc.line("td", s, width=html_width, style="background-color: #1de9B6")
                 if s != "100.00%":
                     doc.line("td", NBSP, style="background-color: #2e3951")
             else:
